select

Function select 

pub fn select(start: Point, end: Point, target: Target) -> impl Operation
Available on crate feature advanced only.
Selects text between the given positions in layout coordinates.

start is the position where the user started selecting from, while end is the final position of the selection.